Decoration class

Constructors

Decoration({Color? color, Unit? height, Unit? width, EdgeInsets? padding, EdgeInsets? margin, BorderRadius? borderRadius, Border? border, BoxShadow? shadow, double? opacity, Display? display, JustifyContent? verticalAlign, AlignItems? horizontalAlign})

Properties

border → Border?
final
borderRadius → BorderRadius?
final
color → Color?
final
display → Display?
final
hashCode int
The hash code for this object.
no setterinherited
height → Unit?
final
horizontalAlign → AlignItems?
final
margin → EdgeInsets?
final
opacity double?
final
padding → EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow → BoxShadow?
final
verticalAlign → JustifyContent?
final
width → Unit?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited