Icons class
Constructors
- Icons()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- address_book_filled → const String
- adjustments → const String
- adjustments_vertical → const String
- annotation → const String
- apple → const String
- archive → const String
- archive_arrow_down → const String
- arrow_right → const String
- arrow_up_right → const String
- award → const String
- backward_start → const String
- badge_check → const String
- bell → const String
- bell_active → const String
- bell_active_alt → const String
- bell_ring → const String